@@ -9,14 +9,14 @@ T = TypeVar("T")
 LEAN_CLASS_KEY = "__leanapi_class__"
 
 
-def controller(path: str, router: APIRouter) -> Callable[[Type[T]], Type[T]]:
+def controller(path: str, router: APIRouter, depend: Callable[None] = None) -> Callable[[Type[T]], Type[T]]:
     def decorator(cls: Type[T]) -> Type[T]:
-        return _controller(router, path, cls)
+        return _controller(router, path, cls, [Depends(_call)] if _call else None)
 
     return decorator
 
 
-def _controller(router: APIRouter, path: str, cls: Type[T]) -> Type[T]:
+def _controller(router: APIRouter, path: str, cls: Type[T], _call:Any) -> Type[T]:
     """
     Replaces any methods of the provided class `cls` that are endpoints of routes in `router` with updated
     function calls that will properly inject an instance of `cls`.
@@ -34,7 +34,7 @@ def _controller(router: APIRouter, path: str, cls: Type[T]) -> Type[T]:
         router.routes.remove(route)
         _update_controller_route_endpoint_signature(cls, route)
         cbv_router.routes.append(route)
-    router.include_router(cbv_router, prefix=f"/{path}")
+    router.include_router(cbv_router, prefix=f"/{path}", dependencies=_call, tags=[path])
     return cls
 
 
@@ -88,3 +88,5 @@ def _update_controller_route_endpoint_signature(cls: Type[Any], route: Union[Rou
     ]
     new_signature = old_signature.replace(parameters=new_parameters)
     setattr(route.endpoint, "__signature__", new_signature)
+
+    
